@@ -1,27 +1,13 @@
 from functools import wraps
-from typing import Any, Callable, Dict, Type, TypeVar, Union
+from typing import Any, Callable, Dict, Optional, Type, TypeVar, Union
 
-from apischema.json_schema.types import JsonType
+from apischema.json_schema.types import bad_type
 from apischema.types import NoneType
-from apischema.validation.errors import ValidationError
 
 T = TypeVar("T")
 
 Coercer = Callable[[Type[T], Any], T]
 
-
-def no_coercion(expected: Type[T], data: Any) -> T:
-    if not isinstance(data, expected):
-        if expected is float and isinstance(data, int):
-            return float(data)  # type: ignore
-        msg = (
-            f"expected type {JsonType.from_type(expected)},"
-            f" found {JsonType.from_type(type(data))}"
-        )
-        raise ValidationError([msg])
-    return data
-
-
 _bool_pairs = (
     ("0", "1"),
     ("f", "t"),
@@ -38,14 +24,6 @@ for false, true in _bool_pairs:
 STR_NONE_VALUES = {""}
 
 
-def coercion_error(cls: Type, data) -> ValidationError:
-    msg = (
-        f"cannot coerce {JsonType.from_type(cls)}"
-        f" from {JsonType.from_type(type(data))}"
-    )
-    return ValidationError([msg])
-
-
 def coerce(cls: Type[T], data: Any) -> T:
     try:
         if isinstance(data, cls):
@@ -60,12 +38,12 @@ def coerce(cls: Type[T], data: Any) -> T:
             raise ValueError
         return cls(data)  # type: ignore
     except (ValueError, TypeError, KeyError):
-        raise coercion_error(cls, data) from None
+        raise bad_type(data, cls)
 
 
 _coercer: Coercer = coerce
 
-Coercion = Union[bool, Coercer]
+Coerce = Union[bool, Coercer]
 
 
 def wrap_coercer(coercer: Coercer) -> Coercer:
@@ -76,18 +54,18 @@ def wrap_coercer(coercer: Coercer) -> Coercer:
         except AssertionError:
             raise
         except Exception:
-            raise coercion_error(cls, data)
+            raise bad_type(data, cls)
         if not isinstance(result, cls):
-            raise coercion_error(cls, data)
+            raise bad_type(data, cls)
         return result
 
     return wrapper
 
 
-def get_coercer(coercion: Coercion) -> Coercer:
-    if callable(coercion):
-        return wrap_coercer(coercion)
-    elif coercion:
+def get_coercer(coerce: Coerce) -> Optional[Coercer]:
+    if callable(coerce):
+        return wrap_coercer(coerce)
+    elif coerce:
         return _coercer
     else:
-        return no_coercion
+        return None
