@@ -2,23 +2,25 @@ __all__ = [
     "alias",
     "conversion",
     "default_as_set",
-    "default_fallback",
+    "fall_back_on_default",
+    "flattened",
     "init_var",
-    "merged",
     "post_init",
     "properties",
     "required",
+    "schema",
     "skip",
     "validators",
 ]
 
 from apischema.aliases import alias
+from apischema.schemas import schema
 from .implem import (
     conversion,
     default_as_set,
-    default_fallback,
+    fall_back_on_default,
+    flattened,
     init_var,
-    merged,
     post_init,
     properties,
     required,
